@@ -40,6 +40,10 @@ func createEphemeralObjects(ctx context.Context, base *NucleiEngine, opts *types
 		Colorizer:       aurora.NewAurora(true),
 		ResumeCfg:       types.NewResumeCfg(),
 		Parser:          base.parser,
+		Browser:         base.browserInstance,
+	}
+	if opts.ShouldUseHostError() && base.hostErrCache != nil {
+		u.executerOpts.HostErrorsCache = base.hostErrCache
 	}
 	if opts.RateLimitMinute > 0 {
 		opts.RateLimit = opts.RateLimitMinute
